@@ -28,12 +28,10 @@
 #define LIBGNOMEUIP_H
 
 #include <glib.h>
-#include <gobject/gsignal.h>
 #include <gtk/gtktypeutils.h>
 
 
-#include <libgnome.h>
-#include "gnome-macros.h"
+#include <libgnome/libgnome.h>
 #include "gnometypebuiltins.h"
 #include "gnome-gconf-ui.h"
 
@@ -41,6 +39,17 @@ G_BEGIN_DECLS
 
 void gnome_type_init(void);
 
+#ifdef G_OS_WIN32
+const char *_gnome_ui_get_localedir      (void);
+const char *_gnome_ui_get_datadir        (void);
+
+#undef GNOMEUILOCALEDIR
+#define GNOMEUILOCALEDIR _gnome_ui_get_localedir()
+#undef LIBGNOMEUI_DATADIR
+#define LIBGNOMEUI_DATADIR _gnome_ui_get_datadir()
+
+#endif
+
 G_END_DECLS
 
 #endif /* LIBGNOMEUIP_H */
